summaryrefslogtreecommitdiff
path: root/src/graphicsmanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/graphicsmanager.cpp')
-rw-r--r--src/graphicsmanager.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/graphicsmanager.cpp b/src/graphicsmanager.cpp
index f45439937..57809f255 100644
--- a/src/graphicsmanager.cpp
+++ b/src/graphicsmanager.cpp
@@ -1,8 +1,8 @@
/*
* The ManaPlus Client
* Copyright (C) 2012-2019 The ManaPlus Developers
*
* This file is part of The ManaPlus Client.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -622,7 +622,7 @@ SDL_Window *GraphicsManager::createWindow(const int w, const int h,
const int bpp A_UNUSED,
const int flags)
{
- return SDL_CreateWindow("ManaPlus", SDL_WINDOWPOS_UNDEFINED,
+ return SDL_CreateWindow("ManaVerse", SDL_WINDOWPOS_UNDEFINED,
SDL_WINDOWPOS_UNDEFINED, w, h, flags);
}
@@ -1,8 +1,8 @@
/*
- * The ManaPlus Client
+ * The ManaVerse Client
* Copyright (C) 2012-2019 The ManaPlus Developers
*
@@ -1,8 +1,8 @@
* Copyright (C) 2012-2019 The ManaPlus Developers
*
- * This file is part of The ManaPlus Client.
+ * This file is part of The ManaVerse Client.
*
* This program is free software; you can redistribute it and/or modify